[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
15/25: gnu: chez-scheme: Use "lib/chez-scheme" for search path.
From: |
guix-commits |
Subject: |
15/25: gnu: chez-scheme: Use "lib/chez-scheme" for search path. |
Date: |
Fri, 4 Mar 2022 17:54:14 -0500 (EST) |
lilyp pushed a commit to branch master
in repository guix.
commit 2a3946bae9f8297ca9763b1f83a349edaa836d4d
Author: Philip McGrath <philip@philipmcgrath.com>
AuthorDate: Sun Feb 27 16:29:11 2022 -0500
gnu: chez-scheme: Use "lib/chez-scheme" for search path.
There does not seem to be any widely accepted standard path to use for
"CHEZSCHEMELIBDIRS". Using a path without a version number in it avoids
having to compute the actual path everywhere, which would be especially
unpleasant when support is added for the Racket variant of Chez Scheme,
which always has a different version number than upstream.
* gnu/packages/chez.scm (chez-scheme)[native-search-paths]: Change to
use "lib/chez-scheme" instead of "lib/csvX.Y.Z-site" for
"CHEZSCHEMELIBDIRS".
(chez-make-flags): Update accordingly.
(chez-sockets)[arguments]<#:phases>: Likewise.
Signed-off-by: Liliana Marie Prikler <liliana.prikler@gmail.com>
---
gnu/packages/chez.scm | 16 ++++++----------
1 file changed, 6 insertions(+), 10 deletions(-)
diff --git a/gnu/packages/chez.scm b/gnu/packages/chez.scm
index 4ee9711bb4..f4c87fbcf7 100644
--- a/gnu/packages/chez.scm
+++ b/gnu/packages/chez.scm
@@ -233,7 +233,7 @@ If native threads are supported, the returned list will
include
(native-search-paths
(list (search-path-specification
(variable "CHEZSCHEMELIBDIRS")
- (files (list (string-append "lib/csv" version "-site"))))))
+ (files '("lib/chez-scheme")))))
(outputs '("out" "doc"))
(arguments
`(#:modules
@@ -458,9 +458,9 @@ Chez Scheme.")
(define (chez-make-flags name version)
#~(let ((out #$output))
(list
- ;; Set 'chezversion' so that libraries are installed in
- ;; 'lib/csvX.Y.Z-site' like Chez's 'native-search-paths' expects.
- (string-append "chezversion=" #$(package-version chez-scheme))
+ ;; Set 'schemedir' so that libraries are installed in
+ ;; 'lib/chez-scheme' like Chez's 'native-search-paths' expects.
+ (string-append "schemedir=" out "/lib/chez-scheme")
(string-append "PREFIX=" out)
(string-append "DOCDIR=" out "/share/doc/" #$name "-" #$version))))
@@ -608,9 +608,7 @@ programming in Scheme.")
(replace 'build
(lambda args
(let ((chez-site (string-append #$output
- "/lib/csv"
- (package-version chez-scheme)
- "-site/arcfide")))
+ "/lib/chez-scheme/arcfide")))
;; make sure Chez Scheme can find the shared libraries.
(substitute* "sockets.ss"
(("(object \")(socket-ffi-values\\.[sd][oy][^\"]*)(\")"
@@ -634,9 +632,7 @@ programming in Scheme.")
(lambda args
(install-file "sockets.so"
(string-append #$output
- "/lib/csv"
- #$(package-version chez-scheme)
- "-site/arcfide"))
+ "/lib/chez-scheme/arcfide"))
(install-file "sockets.pdf"
(string-append #$output
"/share/doc/"
- branch master updated (b5f654b238 -> 97065f9fe3), guix-commits, 2022/03/04
- 03/25: gnu: racket: Use Git origins for Racket packages., guix-commits, 2022/03/04
- 05/25: gnu: racket-minimal: Don't configure non-existant catalogs., guix-commits, 2022/03/04
- 07/25: gnu: racket-minimal: Adjust indentation., guix-commits, 2022/03/04
- 08/25: gnu: racket-minimal: Add "debug" output., guix-commits, 2022/03/04
- 25/25: gnu: komikku: Update to 0.37.0., guix-commits, 2022/03/04
- 14/25: gnu: chez-scheme: Use new style for Chez packages., guix-commits, 2022/03/04
- 11/25: gnu: racket: Move Chez bootfiles to (gnu packages chez)., guix-commits, 2022/03/04
- 13/25: gnu: racket: Add 'racket-vm-for-system'., guix-commits, 2022/03/04
- 12/25: gnu: chez: Add utilities for Chez machine types., guix-commits, 2022/03/04
- 15/25: gnu: chez-scheme: Use "lib/chez-scheme" for search path.,
guix-commits <=
- 09/25: gnu: configure-layer.rkt: Adjust indentation., guix-commits, 2022/03/04
- 16/25: gnu: chez-scheme: Use shared zlib and lz4., guix-commits, 2022/03/04
- 23/25: gnu: chez: Add 'chez-scheme-for-system'., guix-commits, 2022/03/04
- 19/25: gnu: Add chez-nanopass., guix-commits, 2022/03/04
- 04/25: gnu: racket-minimal: Use new package style., guix-commits, 2022/03/04
- 06/25: gnu: racket-minimal: Change inheritance to follow bootstrapping., guix-commits, 2022/03/04
- 10/25: gnu: racket-minimal: Separate from the Racket VM., guix-commits, 2022/03/04
- 22/25: gnu: Add chez-scheme-for-racket., guix-commits, 2022/03/04
- 01/25: gnu: Use license prefix in (gnu packages racket)., guix-commits, 2022/03/04
- 02/25: gnu: racket: Update to 8.4., guix-commits, 2022/03/04